@@ -9,7 +9,6 @@ from hepdata_validator import LATEST_SCHEMA_VERSION
 from hepdata_validator.submission_file_validator import SubmissionFileValidator
 from hepdata_validator.data_file_validator import DataFileValidator
 from hepdata_converter.parsers import Parser, ParsedData, Table
-from multiprocessing import Pool
 import os, re
 
 # Allow for a bug in PyYAML where numbers like 1e+04 are parsed as strings not as floats.
@@ -31,8 +30,6 @@ class YAML(Parser):
            'the directory where submission.yaml file ' \
            'is present (or direct filepath to the submission.yaml file)'
 
-    pool = Pool()
-
     def __init__(self, *args, **kwargs):
         super(YAML, self).__init__(*args, **kwargs)
         self.validator_schema_version = kwargs.get('validator_schema_version', LATEST_SCHEMA_VERSION)
@@ -41,7 +38,7 @@ class YAML(Parser):
     def _pretty_print_errors(self, message_dict):
         return ' '.join(
                 ['%s: %s' % (key, ' | '.join([e.message for e in val])) for
-                 key, val in message_dict.items()])
+                 key, val in list(message_dict.items())])
 
     def parse(self, data_in, *args, **kwargs):
         """
