@@ -14,7 +14,9 @@ class YODAWriterTestSuite(WriterTestSuite):
         output_file_path = os.path.join(self.current_tmp, 'datafile.yoda')
         hepdata_converter.convert(yaml_simple_path, output_file_path,
                                   options={'output_format': 'yoda',
-                                           'validator_schema_version': '0.1.0'})
+                                           'validator_schema_version': '0.1.0',
+                                           'hepdata_doi': '10.17182/hepdata.62535.v1',
+                                           'rivet_analysis_name': 'ATLAS_2012_I1203852'})
 
         self.assertNotEqual(os.stat(output_file_path).st_size, 0, 'output yoda file is empty')
         with open(output_file_path, 'r') as f:
